module ov5640_udp_mdio(
    Clk,
	Rst_n,
	
	GMII_GTXC,
	GMII_TXD,
	GMII_TXEN,

	ETH_Rst_n,
	ETH_MDIO,
	ETH_MDC,
	
	cmos_sclk,
	cmos_sdat,
	cmos_vsync,
	cmos_href,
	cmos_pclk,
	cmos_xclk,
	cmos_data,
	cmos_rst_n,
	cmos_pwdn
);
	input Clk;
	input Rst_n;
	
	output GMII_GTXC;
	
	output [7:0] GMII_TXD;
	output GMII_TXEN;
	output ETH_Rst_n;
	inout ETH_MDIO;
	output ETH_MDC;
	
	//cmos interface
	output		cmos_sclk;
	inout		cmos_sdat;
	input		cmos_vsync;
	input		cmos_href;
	input		cmos_pclk;
	output		cmos_xclk;
	input [7:0] cmos_data;
	output		cmos_rst_n;
	output		cmos_pwdn;
	
	localparam RGB = 0;
	localparam JPEG = 1;
	
	parameter IMAGE_WIDTH  = 640; //图片宽度
	parameter IMAGE_HEIGHT = 480; //图片高度(≤720)
	parameter IMAGE_FLIP   = 0;   //0：不翻转，1：上下翻转
	parameter IMAGE_MIRROR = 0;   //0：不镜像，1：左右镜像
	
	//assign ETH_Rst_n = 1;
	assign cmos_pwdn = 1'b0;

	pll pll(
		.inclk0(Clk),
		.c0(GMII_GTXC),
		.c1(cmos_xclk)
	);
	
	phy_reg_config u_phy_config(
		.clock_50m	(Clk       ),
		.reset_n    (Rst_n     ),
		.phy_rst_n  (ETH_Rst_n ),
		.phy_reg    (          ),
		.phy_mdc    (ETH_MDC   ),
		.phy_mdio   (ETH_MDIO  ),
		.phy_init   (          )
	);
	
	//-----------------------------------------------
	//摄像头初始化配置
	wire Init_Done;
	cmos_init
	#(
		.IMAGE_TYPE(RGB),
		.IMAGE_WIDTH(IMAGE_WIDTH),
		.IMAGE_HEIGHT(IMAGE_HEIGHT),
		.IMAGE_FLIP(IMAGE_FLIP),
		.IMAGE_MIRROR(IMAGE_MIRROR)
	)
	cmos_init(
		.Clk(Clk),
		.Rst_n(Rst_n),
		.Init_Done(Init_Done),
		.cmos_rst_n(cmos_rst_n),
		.i2c_sclk(cmos_sclk),
		.i2c_sdat(cmos_sdat)
	);
	
	wire fifo_aclr;
	wire fifo_wrreq;
	wire [7:0] fifo_wrdata;
	wire [12:0] fifo_usedw;
	cmos_capture_rgb565 cmos_capture_rgb565(
		.cmos_pclk(cmos_pclk),
		.Rst_n(Rst_n),
		.Init_Done(Init_Done),
		.cmos_vsync(cmos_vsync),
		.cmos_href(cmos_href),
		.cmos_data(cmos_data),
		.fifo_aclr(fifo_aclr),
		.fifo_wrreq(fifo_wrreq),
		.fifo_wrdata(fifo_wrdata)
	);
	
	UDP_Send UDP_Send(
		.Clk(),
		.GMII_GTXC(GMII_GTXC),
		.GMII_TXD(GMII_TXD),
		.GMII_TXEN(GMII_TXEN),
		.Rst_n(Init_Done),
		.Tx_Done(),
		.data_length(IMAGE_WIDTH*2+2),
		.des_ip(32'hc0_a8_00_03),
		.des_mac(48'hFF_FF_FF_FF_FF_FF),
		.des_port(16'd6000),
		.src_ip(32'hc0_a8_00_02),
		.src_mac(48'h00_0a_35_01_fe_c0),
		.src_port(16'd5000),
		.wrclk(cmos_pclk),
		.wrdata(fifo_wrdata),
		.wrreq(fifo_wrreq),
		.aclr(fifo_aclr),
		.wrusedw(fifo_usedw)
	);
	
endmodule
